==> conc-2.0.1.tar.gz: conc-2.0.1/client/error.c <==
#include <stdarg.h>
#include "error.h"

/* 
 * Glade widget names:
 */
#define ERROR_DIALOG			"error dialog"
#define ERROR_DIALOG_MSG		"label"
#define WARNING_DIALOG			"warning dialog"
#define WARNING_DIALOG_MSG		"label"
#define INFO_DIALOG			"info dialog"
#define INFO_DIALOG_MSG			"label"

/*
 * Glade handler names:
 */
#define WARNING_DIALOG_RESPONSE		"response"
#define INFO_DIALOG_RESPONSE		"response"


#define ERR_FMT "<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s"

extern void
error_dialog(Conc *conc,
	const gchar *primary_text,
	const gchar *secondary_text,
	...) {
    GladeXML *error = glade_xml_new(conc->glade_file, ERROR_DIALOG, NULL);
    gchar *secondary;
    gchar *text;
    va_list args;

    va_start(args, secondary_text);
    secondary = g_strdup_vprintf(secondary_text, args);
    va_end(args);
    text = g_strdup_printf(ERR_FMT, primary_text, secondary);
    g_free(secondary);

    gtk_label_set_markup(GTK_LABEL(glade_xml_get_widget(error,
		    ERROR_DIALOG_MSG)), text);
    g_free(text);

    gtk_dialog_run(GTK_DIALOG(glade_xml_get_widget(error, ERROR_DIALOG)));
    gtk_widget_destroy(glade_xml_get_widget(error, ERROR_DIALOG));
    
    gtk_main_quit();
}

static void
error_dialog_done(GtkDialog *dialog,
        gint arg1,
        gpointer user_data) {
    gtk_widget_destroy(GTK_WIDGET(dialog));
}

extern void
warning_dialog(Conc *conc,
	const gchar *primary_text,
	const gchar *secondary_text,
	...) {
    GladeXML *error = glade_xml_new(conc->glade_file, WARNING_DIALOG, NULL);
    gchar *secondary;
    gchar *text;
    va_list args;

    va_start(args, secondary_text);
    secondary = g_strdup_vprintf(secondary_text, args);
    va_end(args);
    text = g_strdup_printf(ERR_FMT, primary_text, secondary);
    g_free(secondary);

    gtk_label_set_markup(GTK_LABEL(glade_xml_get_widget(error,
		    WARNING_DIALOG_MSG)), text);
    g_free(text);
    glade_xml_signal_connect(error, WARNING_DIALOG_RESPONSE,
	    (GCallback)error_dialog_done);
}

extern void
info_dialog(Conc *conc,
	const gchar *primary_text,
	const gchar *secondary_text,
	...) {
    GladeXML *error = glade_xml_new(conc->glade_file, INFO_DIALOG, NULL);
    gchar *secondary;
    gchar *text;
    va_list args;

    va_start(args, secondary_text);
    secondary = g_strdup_vprintf(secondary_text, args);
    va_end(args);
    text = g_strdup_printf(ERR_FMT, primary_text, secondary);
    g_free(secondary);

    gtk_label_set_markup(GTK_LABEL(glade_xml_get_widget(error,
		    INFO_DIALOG_MSG)), text);
    g_free(text);
    glade_xml_signal_connect(error, INFO_DIALOG_RESPONSE,
	    (GCallback)error_dialog_done);
}

==> conc-2.0.3.tar.gz: conc-2.0.3/client/error.c <==
#include <stdarg.h>
#include "error.h"

/* 
 * Glade widget names:
 */
#define ERROR_DIALOG			"error dialog"
#define ERROR_DIALOG_MSG		"edlabel"
#define WARNING_DIALOG			"warning dialog"
#define WARNING_DIALOG_MSG		"wdlabel"
#define INFO_DIALOG			"info dialog"
#define INFO_DIALOG_MSG			"idlabel"

/*
 * Glade handler names:
 */
#define WARNING_DIALOG_RESPONSE		"response"
#define INFO_DIALOG_RESPONSE		"response"


#define ERR_FMT "<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s"

extern void
error_dialog(Conc *conc,
	const gchar *primary_text,
	const gchar *secondary_text,
	...) {
    GladeXML *error = glade_xml_new(conc->glade_file, ERROR_DIALOG, NULL);
    gchar *secondary;
    gchar *text;
    va_list args;

    va_start(args, secondary_text);
    secondary = g_strdup_vprintf(secondary_text, args);
    va_end(args);
    text = g_strdup_printf(ERR_FMT, primary_text, secondary);
    g_free(secondary);

    gtk_label_set_markup(GTK_LABEL(glade_xml_get_widget(error,
		    ERROR_DIALOG_MSG)), text);
    g_free(text);

    gtk_dialog_run(GTK_DIALOG(glade_xml_get_widget(error, ERROR_DIALOG)));
    gtk_widget_destroy(glade_xml_get_widget(error, ERROR_DIALOG));
    
    gtk_main_quit();
}

static void
error_dialog_done(GtkDialog *dialog,
        gint arg1,
        gpointer user_data) {
    gtk_widget_destroy(GTK_WIDGET(dialog));
}

extern void
warning_dialog(Conc *conc,
	const gchar *primary_text,
	const gchar *secondary_text,
	...) {
    GladeXML *error = glade_xml_new(conc->glade_file, WARNING_DIALOG, NULL);
    gchar *secondary;
    gchar *text;
    va_list args;

    va_start(args, secondary_text);
    secondary = g_strdup_vprintf(secondary_text, args);
    va_end(args);
    text = g_strdup_printf(ERR_FMT, primary_text, secondary);
    g_free(secondary);

    gtk_label_set_markup(GTK_LABEL(glade_xml_get_widget(error,
		    WARNING_DIALOG_MSG)), text);
    g_free(text);
    glade_xml_signal_connect(error, WARNING_DIALOG_RESPONSE,
	    (GCallback)error_dialog_done);
}

extern void
info_dialog(Conc *conc,
	const gchar *primary_text,
	const gchar *secondary_text,
	...) {
    GladeXML *error = glade_xml_new(conc->glade_file, INFO_DIALOG, NULL);
    gchar *secondary;
    gchar *text;
    va_list args;

    va_start(args, secondary_text);
    secondary = g_strdup_vprintf(secondary_text, args);
    va_end(args);
    text = g_strdup_printf(ERR_FMT, primary_text, secondary);
    g_free(secondary);

    gtk_label_set_markup(GTK_LABEL(glade_xml_get_widget(error,
		    INFO_DIALOG_MSG)), text);
    g_free(text);
    glade_xml_signal_connect(error, INFO_DIALOG_RESPONSE,
	    (GCallback)error_dialog_done);
}
